# Examples

The example notebooks have several dependencies. You can install all the dependencies
using `micromamba` (or `conda` or `mamba`):

```bash
micormamba create -n sceua sceua pandas ipykernel ipywidgets
```

This will create a new environment called `sceua` with all the required packages.

<div class="grid cards" markdown>

- [![Calibration](images/convergence.png){ loading=lazy }](calibration.ipynb "Calibration")
    **Calibration**

</div>
